@@ -1,9 +1,9 @@
 #! /bin/sh
 # check script for Lzd - Educational decompressor for the lzip format
-# Copyright (C) 2013-2019 Antonio Diaz Diaz.
+# Copyright (C) 2013-2021 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
-# to copy, distribute and modify it.
+# to copy, distribute, and modify it.
 
 LC_ALL=C
 export LC_ALL
@@ -30,6 +30,8 @@ cd "${objdir}"/tmp || framework_failure
 
 in="${testdir}"/test.txt
 in_lz="${testdir}"/test.txt.lz
+in_em="${testdir}"/test_em.txt.lz
+fox_lz="${testdir}"/fox.lz
 fail=0
 test_failed() { fail=1 ; printf " $1" ; [ -z "$2" ] || printf "($2)" ; }
 
@@ -38,16 +40,38 @@ printf "testing lzd-%s..." "$2"
 "${LZIP}" < "${in}" 2> /dev/null
 [ $? = 2 ] || test_failed $LINENO
 
-"${LZIP}" < "${in_lz}" > copy || test_failed $LINENO
-cmp "${in}" copy || test_failed $LINENO
+for i in "${in_lz}" "${in_em}" ; do
+	"${LZIP}" < "$i" > copy || test_failed $LINENO "$i"
+	cmp "${in}" copy || test_failed $LINENO "$i"
+done
 
 cat "${in}" "${in}" > in2 || framework_failure
 cat "${in_lz}" "${in_lz}" > in2.lz || framework_failure
 "${LZIP}" < in2.lz > copy2 || test_failed $LINENO
 cmp in2 copy2 || test_failed $LINENO
 
+cat in2.lz > copy2.lz || framework_failure
+printf "\ngarbage" >> copy2.lz || framework_failure
+"${LZIP}" -d < copy2.lz > copy2 || test_failed $LINENO
+cmp in2 copy2 || test_failed $LINENO
+rm -f in2 copy2 copy2.lz || framework_failure
+
 printf "\ntesting bad input..."
 
+for i in fox_bm.lz fox_v2.lz fox_s11.lz fox_de20.lz \
+         fox_bcrc.lz fox_crc0.lz fox_das46.lz fox_mes81.lz ; do
+	"${LZIP}" < "${testdir}"/$i > /dev/null 2>&1
+	[ $? = 2 ] || test_failed $LINENO $i
+done
+
+"${LZIP}" < "${fox_lz}" > fox || test_failed $LINENO
+for i in fox_bcrc.lz fox_crc0.lz fox_das46.lz fox_mes81.lz ; do
+	"${LZIP}" < "${testdir}"/$i > out 2> /dev/null
+	[ $? = 2 ] || test_failed $LINENO $i
+	cmp fox out || test_failed $LINENO $i
+done
+rm -f fox out || framework_failure
+
 cat "${in_lz}" "${in_lz}" "${in_lz}" > in3.lz || framework_failure
 if dd if=in3.lz of=trunc.lz bs=14752 count=1 2> /dev/null &&
    [ -e trunc.lz ] && cmp in2.lz trunc.lz > /dev/null 2>&1 ; then
